@@ -1,9 +1,9 @@
 from urllib.parse import ParseResult
 
+import inject
+
 from paf.manager import WebDriverManager
 from paf.request import WebDriverRequest
-from selenium.webdriver import ChromeOptions, Remote
-import inject
 
 
 def test_browser(monkeypatch):
@@ -29,27 +29,12 @@ def test_window_size(monkeypatch):
     assert request.window_size.height == 768
 
 
-def test_chrome_options():
-    request = WebDriverRequest()
+def test_server_url(monkeypatch):
+    monkeypatch.setenv('PAF_SELENIUM_SERVER_URL', "http://127.0.0.1:4444")
+    request = WebDriverRequest("remote")
     request.browser = "chrome"
-    request.options = ChromeOptions()
-    manager = inject.instance(WebDriverManager)
-    webdriver = manager.get_webdriver(request)
-    assert webdriver.name == request.browser
-
-
-def test_remote_webdriver(monkeypatch):
-    server_url = "http://127.0.0.1:4444"
-    monkeypatch.setenv('PAF_SELENIUM_SERVER_URL', server_url)
-    request = WebDriverRequest()
-    request.browser = "chrome"
-    request.options = ChromeOptions()
     assert isinstance(request.server_url, ParseResult)
-    manager = inject.instance(WebDriverManager)
-    webdriver = manager.get_webdriver(request)
-    assert webdriver.name == request.browser
 
 
 def teardown_module():
-    manager = inject.instance(WebDriverManager)
-    manager.shutdown_all()
+    inject.instance(WebDriverManager).shutdown_all()
